#ifndef NT2_INCLUDE_FUNCTIONS_HMSB_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_HMSB_HPP_INCLUDED

#include <nt2/reduction/include/functions/hmsb.hpp>

#endif
